==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/outputs/DeploymentConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.outputs

import com.pulumi.core.Either
import kotlin.Any
import kotlin.String
import kotlin.Suppress

/**
 * Deployment Configuration.
 * @property appLocation The geo-location where the SAP system is to be created.
 * @property configurationType The configuration Type.
 * Expected value is 'Deployment'.
 * @property infrastructureConfiguration The infrastructure configuration.
 * @property softwareConfiguration The software configuration.
 */
public data class DeploymentConfigurationResponse(
    public val appLocation: String? = null,
    public val configurationType: String,
    public val infrastructureConfiguration:
    Either<SingleServerConfigurationResponse, ThreeTierConfigurationResponse>? = null,
    public val softwareConfiguration: Any? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.workloads.outputs.DeploymentConfigurationResponse):
            DeploymentConfigurationResponse = DeploymentConfigurationResponse(
            appLocation = javaType.appLocation().map({ args0 -> args0 }).orElse(null),
            configurationType = javaType.configurationType(),
            infrastructureConfiguration = javaType.infrastructureConfiguration().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.workloads.kotlin.outputs.SingleServerConfigurationResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.workloads.kotlin.outputs.ThreeTierConfigurationResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }).orElse(null),
            softwareConfiguration = javaType.softwareConfiguration().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/outputs/DeploymentConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.outputs

import com.pulumi.core.Either
import kotlin.Any
import kotlin.String
import kotlin.Suppress

/**
 * Deployment Configuration.
 * @property appLocation The geo-location where the SAP system is to be created.
 * @property configurationType The configuration Type.
 * Expected value is 'Deployment'.
 * @property infrastructureConfiguration The infrastructure configuration.
 * @property softwareConfiguration The software configuration.
 */
public data class DeploymentConfigurationResponse(
    public val appLocation: String? = null,
    public val configurationType: String,
    public val infrastructureConfiguration: Either<SingleServerConfigurationResponse, ThreeTierConfigurationResponse>? = null,
    public val softwareConfiguration: Any? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.workloads.outputs.DeploymentConfigurationResponse): DeploymentConfigurationResponse = DeploymentConfigurationResponse(
            appLocation = javaType.appLocation().map({ args0 -> args0 }).orElse(null),
            configurationType = javaType.configurationType(),
            infrastructureConfiguration = javaType.infrastructureConfiguration().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.workloads.kotlin.outputs.SingleServerConfigurationResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.workloads.kotlin.outputs.ThreeTierConfigurationResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }).orElse(null),
            softwareConfiguration = javaType.softwareConfiguration().map({ args0 -> args0 }).orElse(null),
        )
    }
}
